.. StoveOpt documentation master file, created by
   sphinx-quickstart on Fri Jun  7 16:28:41 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to StoveOpt's documentation!
====================================
.. automodule:: StoveOpt.import_geometry
    :members:


.. automodule:: post_processor
    :members:
	
.. automodule:: new_case_setup
    :members:

.. automodule:: import_geometry
    :members:
	
.. automodule:: create_blockmeshfile
    :members:
	
.. automodule:: run_surrounding_cases
    :members:
	
.. automodule:: runner
    :members:
	
	
	
	
.. toctree::
   :maxdepth: 2
   :caption: Contents:



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
